//
//  MyController.m
//  TestLines
//
//  Created by Cameron Hayne on 28/02/06.
//  Copyright 2006 Hayne of Tintagel.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#import "MyController.h"

// private methods
@interface MyController(Private)
- (void)setTitleFromViewSize;
@end

@implementation MyController

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
    //NSLog(@"applicationDidFinishLaunching");
    [self setTitleFromViewSize];
    
    [window useOptimizedDrawing: YES];
    
    float desiredUpdateRate = 60.0;
    float desiredUpdatePeriod = 1.0 / desiredUpdateRate;
    modelUpdateTimer = [[NSTimer scheduledTimerWithTimeInterval: desiredUpdatePeriod
                                                         target: self
                                                       selector: @selector(updateModel:)
                                                       userInfo: nil
                                                        repeats: YES] retain];
}

- (void)dealloc
{
    [modelUpdateTimer release];
    [super dealloc];
}

- (void)setTitleFromViewSize
{
    NSRect viewBnds = [view bounds];
    NSString *title = [NSString stringWithFormat: @"TestLines %d x %d",
                       (int)NSWidth(viewBnds), (int)NSHeight(viewBnds)];
    [window setTitle: title];
}

// this method is invoked via the modelUpdateTimer
- (void)updateModel:(NSTimer *)aTimer
{
    //NSLog(@"MyController.updateModel");
    [model update];
    [view updateWithLines: [model lines]];
}

- (void)windowDidResize:(NSNotification *)aNotification
{
    [self setTitleFromViewSize];
}

- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)theApplication
{
    return YES;
}

@end
