//
//  MyModel.m
//  TestLines
//
//  Created by Cameron Hayne on 28/02/06.
//  Copyright 2006 Hayne of Tintagel.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#import "MyModel.h"
#import "MyLine.h"
#include <stdlib.h>

static double randomFloat()
{
#define ONE_OVER_RAND_MAX (1.0f / RAND_MAX)
    long rnd = random();
    float rndFloat = rnd * ONE_OVER_RAND_MAX;
    return rndFloat;
}

static NSColor * randomColor()
{
    float r = randomFloat();
    float g = randomFloat();
    float b = randomFloat();
    NSColor *color = [NSColor colorWithDeviceRed: r
                                           green: g 
                                            blue: b 
                                           alpha: 1.0];
    return color;
}

static float randomLineWidth() // ranges from 1.0 to 4.0
{
    float lineWidth = 1.0 + 3.0 * randomFloat();
    return lineWidth;
}

static NSPoint randomPoint() // x & y range from 0.0 to 1.0
{
    NSPoint pt = NSMakePoint(randomFloat(), 
                             randomFloat());
    return pt;
}


@implementation MyModel

- (id)init
{
    self = [super init];
    if (self == nil)
        return nil;

    int defaultNumLines = 100;
    lines = [[NSMutableArray arrayWithCapacity: defaultNumLines] retain];
    [self setNumLines: defaultNumLines];
    return self;
}

- (NSArray *)lines
{
    return lines;
}

- (void)dealloc
{
    [lines release];
    [super dealloc];
}

- (int)numLines
{
    return numLines;
}

- (void)setNumLines:(int)aNum
{
    numLines = aNum;
    [self update];
}

- (void)update
{
    [lines removeAllObjects];
    
    for (int i = 0; i < numLines; i++) 
    {
        // get random colour, lineWidth, and start and end points
        NSColor *color = randomColor();
        float width = randomLineWidth();
        NSPoint start = randomPoint();
        NSPoint end = randomPoint();
        
        MyLine *line = [MyLine lineFrom: start 
                                     To: end
                                  Color: color
                                  Width: width];
        [lines addObject: line];
    }
}

@end
